#!/bin/bash
# The following is a list of commands that you will need when deploying your SAS
# software. These commands have been customized according to the contents of your
# software order. The deployment guide will tell you when to use this script. Do
# not attempt to use this script without direction from the deployment guide.

#load order input values
. ./orderinputs.sh

# Set these variables to the location of the directories where the certificates and licenses are located
CERTDIR=ca-certificates
ENTITLEMENTDIR=entitlement-certificates
LICENSESDIR=licenses

# Download the RPM file used to establish yum connectivity to the central SAS
# catalog of repositories

curl -OLv --cert $ENTITLEMENTDIR/entitlement_certificate.pem --cacert $CERTDIR/SAS_CA_Certificate.pem https://ses.sas.download/ses/repos/meta-repo//sas-meta-repo-1-1.noarch.rpm

# Install the downloaded RPM file

yum install sas-meta-repo-1-1.noarch.rpm

# Copy the entitlement certificate into place for use

cp $ENTITLEMENTDIR/entitlement_certificate.pem /etc/pki/sas/private/entitlement_certificate.pem

# remove existing license file if espbase rpm previously installed.
existing_license_dir=$( rpm -ql sas-espbase | grep etc/license$ )
if [ ! -z "$existing_license_dir" ] && [ -d "$existing_license_dir" ]; then
echo "existing license dir is $existing_license_dir"
rm $existing_license_dir/SASViya*
fi

# Install definitions of the specific repositories for the ordered products

yum install $entitledRepos
y
# Update installed SAS packages for dependencies prior to installing new yum groups
yum update $(rpm -qg SAS)

# Install the software

install_yum_groups

license_dir=$( rpm -ql sas-espbase | grep etc/license$ )
if [ -f $LICENSESDIR/$licenseFile ] && [ -d $license_dir ]; then
cp $LICENSESDIR/$licenseFile $license_dir
else
echo "WARN: License file could not be located and will have to be copied manually"
fi
